@@ -29,6 +29,11 @@
 
 #define NOTIFICATION_AREA_ICON "mate-panel-notification-area"
 
+#if GTK_CHECK_VERSION (3, 0, 0)
+#define gtk_hbox_new(X,Y) gtk_box_new(GTK_ORIENTATION_HORIZONTAL,Y)
+#define gtk_vbox_new(X,Y) gtk_box_new(GTK_ORIENTATION_VERTICAL,Y)
+#endif
+
 static guint n_windows = 0;
 
 typedef struct
@@ -160,7 +165,12 @@ create_tray_on_screen (GdkScreen *screen,
   hbox = gtk_hbox_new (FALSE, 12);
   gtk_box_pack_start (GTK_BOX (vbox), hbox, FALSE, FALSE, 0);
   label = gtk_label_new_with_mnemonic ("_Orientation:");
+#if GTK_CHECK_VERSION (3, 16, 0)
+  gtk_label_set_xalign (GTK_LABEL (label), 0.0);
+  gtk_label_set_yalign (GTK_LABEL (label), 0.5);
+#else
   gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
+#endif
   gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, FALSE, 0);
   combo = gtk_combo_box_text_new ();
   gtk_combo_box_text_append_text (GTK_COMBO_BOX_TEXT (combo), "Horizontal");
@@ -171,7 +181,12 @@ create_tray_on_screen (GdkScreen *screen,
 
   label = gtk_label_new (NULL);
   data->count_label = GTK_LABEL (label);
+#if GTK_CHECK_VERSION (3, 16, 0)
+  gtk_label_set_xalign (GTK_LABEL (label), 0.0);
+  gtk_label_set_yalign (GTK_LABEL (label), 0.5);
+#else
   gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
+#endif
   gtk_box_pack_start (GTK_BOX (vbox), label, FALSE, FALSE, 0);
 
   data->tray = na_tray_new_for_screen (screen, GTK_ORIENTATION_HORIZONTAL);
@@ -200,19 +215,28 @@ main (int argc, char *argv[])
 {
   GdkDisplay *display;
   GdkScreen *screen;
+#if !GTK_CHECK_VERSION (3, 0, 0)
   int n_screens, i;
+#endif
 
   gtk_init (&argc, &argv);
 
   gtk_window_set_default_icon_name (NOTIFICATION_AREA_ICON);
 
   display = gdk_display_get_default ();
+#if GTK_CHECK_VERSION (3, 0, 0)
+  screen = gdk_display_get_default_screen (display);
+
+  create_tray_on_screen (screen, FALSE);
+#else
   n_screens =  gdk_display_get_n_screens (display);
   for (i = 0; i < n_screens; ++i) {
     screen = gdk_display_get_screen (display, i);
-
     create_tray_on_screen (screen, FALSE);
+
+  create_tray_on_screen (screen, FALSE);
   }
+#endif
   
   gtk_main ();
 
