@@ -23,11 +23,9 @@
 #include <libwnck/libwnck.h>
 #include <gio/gio.h>
 
-#include <libmate-desktop/mate-aboutdialog.h>
-#if GTK_CHECK_VERSION (3, 0, 0)
 #define MATE_DESKTOP_USE_UNSTABLE_API
+#include <libmate-desktop/mate-aboutdialog.h>
 #include <libmate-desktop/mate-desktop-utils.h>
-#endif
 
 #include "wncklet.h"
 #include "window-list.h"
@@ -124,7 +122,7 @@ static void applet_change_orient(MatePanelApplet* applet, MatePanelAppletOrient
 
 #ifdef WNCK_CHECK_VERSION
 #if WNCK_CHECK_VERSION (3, 4, 6)
-	wnck_tasklist_set_orientation (tasklist->tasklist, new_orient);
+	wnck_tasklist_set_orientation (WNCK_TASKLIST (tasklist->tasklist), new_orient);
 #endif
 #endif
 	tasklist_update(tasklist);
@@ -528,10 +526,7 @@ gboolean window_list_applet_fill(MatePanelApplet* applet)
 
 static void call_system_monitor(GtkAction* action, TasklistData* tasklist)
 {
-#if !GTK_CHECK_VERSION (3, 0, 0)
-	char* argv[2] = {NULL, NULL};
-#endif
-	char* programpath;
+	char *programpath;
 	int i;
 
 	for (i = 0; i < G_N_ELEMENTS(system_monitors); i += 1)
@@ -542,17 +537,9 @@ static void call_system_monitor(GtkAction* action, TasklistData* tasklist)
 		{
 			g_free(programpath);
 
-#if GTK_CHECK_VERSION (3, 0, 0)
 			mate_gdk_spawn_command_line_on_screen(gtk_widget_get_screen(tasklist->applet),
 				      system_monitors[i],
 				      NULL);
-#else
-			argv[0] = system_monitors[i];
-			gdk_spawn_on_screen(gtk_widget_get_screen(tasklist->applet), NULL, argv, NULL,
-				      G_SPAWN_SEARCH_PATH,
-				      NULL, NULL, NULL, NULL);
-#endif
-
 			return;
 		}
 	}
@@ -607,18 +594,6 @@ static void group_windows_toggled(GtkToggleButton* button, TasklistData* tasklis
 	}
 }
 
-/*static void group_button_toggled(GtkToggleButton* button, TasklistData* tasklist)
-{
-	if (gtk_toggle_button_get_active(button))
-	{
-		char* str = g_object_get_data(G_OBJECT(button), "group_value");
-
-		printf("str: %s\n", str);
-		// Add later!
-		//mate_panel_applet_mate_conf_set_string(MATE_PANEL_APPLET(tasklist->applet), "group_button", str, NULL);
-	}
-}*/
-
 static void move_minimized_toggled(GtkToggleButton* button, TasklistData* tasklist)
 {
 	g_settings_set_boolean(tasklist->settings, "move-unminimized-windows", gtk_toggle_button_get_active(button));
@@ -633,7 +608,6 @@ static void display_all_workspaces_toggled(GtkToggleButton* button, TasklistData
 
 static void setup_sensitivity(TasklistData* tasklist, GtkBuilder* builder, const char* wid1, const char* wid2, const char* wid3, const char* key)
 {
-	MatePanelApplet* applet = MATE_PANEL_APPLET(tasklist->applet);
 	GtkWidget* w;
 
 	if (g_settings_is_writable(tasklist->settings, key))
@@ -679,10 +653,6 @@ static void setup_dialog(GtkBuilder* builder, TasklistData* tasklist)
 	tasklist->move_minimized_radio = WID("move_minimized_radio");
 	tasklist->change_workspace_radio = WID("change_workspace_radio");
 
-	/*tasklist->style_group_radio = WID("style_button_radio");
-	tasklist->icon_group_radio = WID("icon_only_radio");
-	tasklist->text_group_radio = WID("text_only_radio");*/
-
 	setup_sensitivity(tasklist, builder, "move_minimized_radio", "change_workspace_radio", NULL, "move-unminimized-windows" /* key */);
 
 	/* Window grouping: */
@@ -696,17 +666,6 @@ static void setup_dialog(GtkBuilder* builder, TasklistData* tasklist)
 	g_signal_connect(G_OBJECT(tasklist->auto_group_radio), "toggled", (GCallback) group_windows_toggled, tasklist);
 	g_signal_connect(G_OBJECT(tasklist->always_group_radio), "toggled", (GCallback) group_windows_toggled, tasklist);
 
-	/* Button list */
-	//button = get_grouping_button(tasklist, tasklist->grouping);
-	//gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(button), TRUE);
-	/*g_object_set_data(G_OBJECT(tasklist->style_group_radio), "group_value", "style");
-	g_object_set_data(G_OBJECT(tasklist->icon_group_radio), "group_value", "icon");
-	g_object_set_data(G_OBJECT(tasklist->text_group_radio), "group_value", "text");
-
-	g_signal_connect(G_OBJECT(tasklist->style_group_radio), "toggled", (GCallback) group_button_toggled, tasklist);
-	g_signal_connect(G_OBJECT(tasklist->icon_group_radio), "toggled", (GCallback) group_button_toggled, tasklist);
-	g_signal_connect(G_OBJECT(tasklist->text_group_radio), "toggled", (GCallback) group_button_toggled, tasklist);*/
-
 	/* move window when unminimizing: */
 	tasklist_update_unminimization_radio(tasklist);
 	g_signal_connect(G_OBJECT(tasklist->move_minimized_radio), "toggled", (GCallback) move_minimized_toggled, tasklist);
