@@ -236,13 +236,14 @@ button_widget_reload_pixbuf (ButtonWidget *button)
 			//FIXME: this is not rendered at button->priv->size
 			GtkIconTheme *icon_theme = gtk_icon_theme_get_default();
 			button->priv->pixbuf = gtk_icon_theme_load_icon (icon_theme,
-							       GTK_STOCK_MISSING_IMAGE,
+							       "image-missing",
 							       GTK_ICON_SIZE_BUTTON,
 							       GTK_ICON_LOOKUP_FORCE_SVG | GTK_ICON_LOOKUP_USE_BUILTIN,
 							       NULL);
 			g_free (error);
 		}
 
+#if !GTK_CHECK_VERSION (3, 0, 0)
 		/* We need to add a child to the button to get the right allocation of the pixbuf.
 		 * When the button is created without a pixbuf, get_preferred_width/height are
 		 * called the first time when the widget is allocated and 0x0 size is cached by
@@ -252,6 +253,7 @@ button_widget_reload_pixbuf (ButtonWidget *button)
 		 * is never used. We are overriding the draw() method, so having a child doesn't
 		 * affect the widget rendering anyway.
 		 */
+#endif
 		gtk_button_set_image (GTK_BUTTON (button), gtk_image_new_from_pixbuf (button->priv->pixbuf));
 	}
 
@@ -429,18 +431,18 @@ button_widget_expose (GtkWidget         *widget,
 #endif
 {
 	ButtonWidget *button_widget;
-	GtkButton *button;
-	GdkWindow *window;
 	int width;
 	int height;
 #if GTK_CHECK_VERSION (3, 0, 0)
 	GtkStyleContext *context;
 	GtkStateFlags state_flags;
 #else
+	GtkButton *button;
+	GdkWindow *window;
 	GtkAllocation allocation;
 	GtkStyle *style;
-#endif
 	GdkRectangle area, image_bound;
+#endif
 	int off;
 	int x, y, w, h;
 	GdkPixbuf *pb = NULL;
@@ -458,14 +460,14 @@ button_widget_expose (GtkWidget         *widget,
 	if (!button_widget->priv->pixbuf_hc && !button_widget->priv->pixbuf)
 		return FALSE;
 
-	button = GTK_BUTTON (widget);
-	window = gtk_widget_get_window (widget);
 #if GTK_CHECK_VERSION (3, 0, 0)
 	state_flags = gtk_widget_get_state_flags (widget);
 	width = gtk_widget_get_allocated_width (widget);
 	height = gtk_widget_get_allocated_height (widget);
 #else
 	gtk_widget_get_allocation (widget, &allocation);
+	button = GTK_BUTTON (widget);
+	window = gtk_widget_get_window (widget);
 #endif
 
 	/* offset for pressed buttons */
@@ -535,13 +537,11 @@ button_widget_expose (GtkWidget         *widget,
 	context = gtk_widget_get_style_context (widget);
 
 	if (button_widget->priv->arrow) {
-		GtkArrowType arrow_type;
-
 		gdouble angle, size;
 		gtk_style_context_save (context);
 		gtk_style_context_set_state (context, state_flags);
 
-		arrow_type = calc_arrow (button_widget->priv->orientation,
+		calc_arrow (button_widget->priv->orientation,
 					 width, height,
 					 &x, &y,
 					 &angle, &size);
@@ -564,11 +564,14 @@ button_widget_expose (GtkWidget         *widget,
 	}
 
 	if (gtk_widget_has_focus (widget)) {
+#if !GTK_CHECK_VERSION (3, 19, 0)
 		gint focus_pad;
+#endif
 
 		gtk_style_context_save (context);
 		gtk_style_context_set_state (context, state_flags);
 
+#if !GTK_CHECK_VERSION (3, 19, 0)
 		gtk_widget_style_get (widget,
 				      "focus-padding", &focus_pad,
 				      NULL);
@@ -576,16 +579,18 @@ button_widget_expose (GtkWidget         *widget,
 		y = focus_pad;
 		w = width - 2 * focus_pad;
 		h = height - 2 * focus_pad;
+#endif
 
 		cairo_save (cr);
+#if GTK_CHECK_VERSION (3, 19, 0)
+		gtk_render_focus (context, cr, 0, 0, width, height);
+#else
 		gtk_render_focus (context, cr, x, y, w, h);
+#endif
 		cairo_restore (cr);
 
 		gtk_style_context_restore (context);
 	}
-
-	return FALSE;
-}
 #else
 	style = gtk_widget_get_style (widget);
 
@@ -623,10 +628,9 @@ button_widget_expose (GtkWidget         *widget,
 		}
 
 	if (gtk_widget_has_focus (widget)) {
-		gint focus_width, focus_pad;
+		gint focus_pad;
 
 		gtk_widget_style_get (widget,
-				      "focus-line-width", &focus_width,
 				      "focus-padding", &focus_pad,
 				      NULL);
 
@@ -641,10 +645,10 @@ button_widget_expose (GtkWidget         *widget,
 				 &event->area, widget, "button",
 				 x, y, width, height);
 	}
-	
+#endif
+
 	return FALSE;
 }
-#endif
 
 #if GTK_CHECK_VERSION (3, 0, 0)
 static void
@@ -652,14 +656,18 @@ button_widget_get_preferred_width (GtkWidget *widget,
 				   gint *minimal_width,
 				   gint *natural_width)
 {
-	ButtonWidget *button_widget = BUTTON_WIDGET (widget);
+ 	ButtonWidget *button_widget = BUTTON_WIDGET (widget);
+	GtkWidget *parent;
+	int size;
 
-	if (button_widget->priv->pixbuf == NULL ) {
-		*minimal_width = *natural_width = 1;
-		return;
-	}
+	parent = gtk_widget_get_parent (widget);
 
-	*minimal_width = *natural_width = gdk_pixbuf_get_width  (button_widget->priv->pixbuf);
+	if (button_widget->priv->orientation & PANEL_HORIZONTAL_MASK)
+		size = gtk_widget_get_allocated_height (parent);
+	else
+		size = gtk_widget_get_allocated_width (parent);
+
+	*minimal_width = *natural_width = size;
 }
 
 static void
@@ -668,13 +676,17 @@ button_widget_get_preferred_height (GtkWidget *widget,
 				    gint *natural_height)
 {
 	ButtonWidget *button_widget = BUTTON_WIDGET (widget);
+	GtkWidget *parent;
+	int size;
 
-	if (button_widget->priv->pixbuf == NULL ) {
-		*minimal_height = *natural_height = 1;
-		return;
-	}
+	parent = gtk_widget_get_parent (widget);
 
-	*minimal_height = *natural_height = gdk_pixbuf_get_height (button_widget->priv->pixbuf);
+	if (button_widget->priv->orientation & PANEL_HORIZONTAL_MASK)
+		size = gtk_widget_get_allocated_height (parent);
+	else
+		size = gtk_widget_get_allocated_width (parent);
+
+	*minimal_height = *natural_height = size;
 }
 #else
 static void
@@ -695,7 +707,6 @@ button_widget_size_allocate (GtkWidget     *widget,
 			     GtkAllocation *allocation)
 {
 	ButtonWidget *button_widget = BUTTON_WIDGET (widget);
-	GtkButton    *button = GTK_BUTTON (widget);
 	int           size;
 
 #if GTK_CHECK_VERSION (3, 0, 0)
@@ -726,6 +737,7 @@ button_widget_size_allocate (GtkWidget     *widget,
 
 #if !GTK_CHECK_VERSION (3, 0, 0)
 	gtk_widget_set_allocation (widget, allocation);
+	GtkButton *button = GTK_BUTTON (widget);
 
 	if (gtk_widget_get_realized (widget)) {
 		gdk_window_move_resize (button->event_window, 
@@ -772,12 +784,14 @@ button_widget_enter_notify (GtkWidget *widget, GdkEventCrossing *event)
 	g_return_val_if_fail (BUTTON_IS_WIDGET (widget), FALSE);
 
 #if GTK_CHECK_VERSION (3, 0, 0)
-	GtkStateFlags state_flags;
+	GtkStateFlags state_flags = gtk_widget_get_state_flags (widget);
 	in_button = state_flags & GTK_STATE_FLAG_PRELIGHT;
 #else
 	in_button = GTK_BUTTON (widget)->in_button;
 #endif
+
 	GTK_WIDGET_CLASS (button_widget_parent_class)->enter_notify_event (widget, event);
+
 #if GTK_CHECK_VERSION (3, 0, 0)
 	state_flags = gtk_widget_get_state_flags (widget);
 	if (in_button != (state_flags & GTK_STATE_FLAG_PRELIGHT) &&
@@ -798,12 +812,14 @@ button_widget_leave_notify (GtkWidget *widget, GdkEventCrossing *event)
 	g_return_val_if_fail (BUTTON_IS_WIDGET (widget), FALSE);
 
 #if GTK_CHECK_VERSION (3, 0, 0)
-	GtkStateFlags state_flags;
+	GtkStateFlags state_flags = gtk_widget_get_state_flags (widget);
 	in_button = state_flags & GTK_STATE_FLAG_PRELIGHT;
 #else
 	in_button = GTK_BUTTON (widget)->in_button;
 #endif
+
 	GTK_WIDGET_CLASS (button_widget_parent_class)->leave_notify_event (widget, event);
+
 #if GTK_CHECK_VERSION (3, 0, 0)
 	state_flags = gtk_widget_get_state_flags (widget);
 	if (in_button != (state_flags & GTK_STATE_FLAG_PRELIGHT) &&
