@@ -114,6 +114,8 @@ static void panel_menu_bar_update_visibility (GSettings* settings, gchar* key, P
 {
 	GtkWidget* image;
 	gchar *str;
+	GtkIconSize icon_size;
+	gint icon_height;
 
 	if (!GTK_IS_WIDGET (menubar))
 		return;
@@ -125,15 +127,18 @@ static void panel_menu_bar_update_visibility (GSettings* settings, gchar* key, P
 	if (g_settings_get_boolean (settings, PANEL_MENU_BAR_SHOW_ICON_KEY))
 	{
 		str = g_settings_get_string (settings, PANEL_MENU_BAR_ICON_NAME_KEY);
+		icon_size = panel_menu_bar_icon_get_size ();
+		gtk_icon_size_lookup (icon_size, NULL, &icon_height);
 		if (str != NULL && str[0] != 0)
-			image = gtk_image_new_from_icon_name(str, panel_menu_bar_icon_get_size());
+			image = gtk_image_new_from_icon_name(str, icon_size);
 		else
-			image = gtk_image_new_from_icon_name(PANEL_ICON_MAIN_MENU, panel_menu_bar_icon_get_size());
+			image = gtk_image_new_from_icon_name(PANEL_ICON_MAIN_MENU, icon_size);
+		gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (menubar->priv->applications_item), image);
+		gtk_image_set_pixel_size (GTK_IMAGE (image), icon_height);
 		g_free (str);
 	}
 	else
-		image = NULL;
-	gtk_image_menu_item_set_image(GTK_IMAGE_MENU_ITEM(menubar->priv->applications_item), image);
+		gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (menubar->priv->applications_item), NULL);
 }
 
 static void panel_menu_bar_init(PanelMenuBar* menubar)
@@ -269,8 +274,11 @@ static void panel_menu_bar_size_allocate(GtkWidget* widget, GtkAllocation* alloc
 		return;
 	}
 
+#if GTK_CHECK_VERSION (3, 18, 0)
+	background = &PANEL_MENU_BAR(widget)->priv->panel->toplevel->background;
+#else
 	background = &PANEL_MENU_BAR(widget)->priv->panel->background;
-
+#endif
 	if (background->type == PANEL_BACK_NONE || (background->type == PANEL_BACK_COLOR && !background->has_alpha))
 	{
 		return;
@@ -478,8 +486,10 @@ void panel_menu_bar_popup_menu(PanelMenuBar* menubar, guint32 activate_time)
 
 void panel_menu_bar_change_background(PanelMenuBar* menubar)
 {
-#if GTK_CHECK_VERSION (3, 0, 0)
-	panel_background_apply_css(GTK_WIDGET(menubar), &menubar->priv->panel->background);
+#if GTK_CHECK_VERSION (3, 18, 0)
+	panel_background_apply_css(&menubar->priv->panel->toplevel->background, GTK_WIDGET(menubar));
+#elif GTK_CHECK_VERSION (3, 0, 0)
+	panel_background_apply_css(&menubar->priv->panel->background, GTK_WIDGET(menubar));
 #else
 	panel_background_change_background_on_widget(&menubar->priv->panel->background, GTK_WIDGET(menubar));
 #endif
@@ -512,7 +522,12 @@ static void set_item_text_angle_and_alignment(GtkWidget* item, double text_angle
 
 	gtk_label_set_angle (GTK_LABEL (label), text_angle);
 
+#if GTK_CHECK_VERSION (3, 16, 0)
+	gtk_label_set_xalign (GTK_LABEL (label), xalign);
+	gtk_label_set_yalign (GTK_LABEL (label), yalign);
+#else
 	gtk_misc_set_alignment (GTK_MISC (label), xalign, yalign);
+#endif
 }
 
 static void panel_menu_bar_update_orientation(PanelMenuBar* menubar)
